@@ -25,6 +25,7 @@
 
 #include "akregator_part.h"
 #include "akregator_debug.h"
+#include "helper_p.h"
 #include "config-akregator.h"
 #include "messageviewer/messageviewersettings.h"
 #include "akregatorconfig.h"
@@ -187,7 +188,7 @@ namespace Akregator
 
 K_PLUGIN_FACTORY(AkregatorFactory, registerPlugin<Part>();)
 
-static Part *mySelf = Q_NULLPTR;
+static Part *mySelf = nullptr;
 BrowserExtension::BrowserExtension(Part *p, const char *name)
     : KParts::BrowserExtension(p)
 {
@@ -221,7 +222,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     setPluginLoadingMode(LoadPluginsIfEnabled);
     setPluginInterfaceVersion(AKREGATOR_PLUGIN_INTERFACE_VERSION);
 
-    setComponentName(QStringLiteral("akregator"), QStringLiteral("akregator"));
+    setComponentName(QStringLiteral("akregator"), i18n("Akregator"));
     setXMLFile(QStringLiteral("akregator_part.rc"), true);
 
     new PartAdaptor(this);
@@ -281,7 +282,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
             trayIcon->setStatus(KStatusNotifierItem::Active);
         }
 
-        QWidget *const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : Q_NULLPTR;
+        QWidget *const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : nullptr;
         NotificationManager::self()->setWidget(notificationParent, componentData().componentName());
 
         connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
@@ -334,7 +335,7 @@ void Part::loadPlugins(const QString &type)
 {
     const KService::List offers = PluginManager::query(QStringLiteral("[X-KDE-akregator-plugintype] == '%1'").arg(type));
 
-    Q_FOREACH (const KService::Ptr &i, offers) {
+    for (const KService::Ptr &i : offers) {
         Akregator::Plugin *plugin = PluginManager::createFromService(i, this);
         if (!plugin) {
             continue;
@@ -346,7 +347,7 @@ void Part::loadPlugins(const QString &type)
 
 void Part::slotStarted()
 {
-    Q_EMIT started(Q_NULLPTR);
+    Q_EMIT started(nullptr);
 }
 
 void Part::slotOnShutdown()
@@ -361,7 +362,7 @@ void Part::slotOnShutdown()
     }
     //delete m_mainWidget;
     delete TrayIcon::getInstance();
-    TrayIcon::setInstance(Q_NULLPTR);
+    TrayIcon::setInstance(nullptr);
     delete m_storage;
     m_storage = 0;
     //delete m_actionManager;
@@ -521,7 +522,7 @@ void Part::feedListLoaded(const QSharedPointer<FeedList> &list)
 
 void Part::flushAddFeedRequests()
 {
-    Q_FOREACH (const AddFeedRequest &i, m_requests) {
+    for (const AddFeedRequest &i : qAsConst(m_requests)) {
         Q_FOREACH (const QString &j, i.urls) {
             m_mainWidget->addFeedToGroup(j, i.group);
         }
@@ -539,7 +540,7 @@ void Part::slotSaveFeedList()
 
     // the first time we overwrite the feed list, we create a backup
     if (!m_backedUpList) {
-        const QString backup = localFilePath() + QStringLiteral("~");
+        const QString backup = localFilePath() + QLatin1Char('~');
         if (QFile::copy(localFilePath(), backup)) {
             m_backedUpList = true;
         }
