@@ -25,6 +25,7 @@
 #include "folder.h"
 #include "article.h"
 #include "articlejobs.h"
+#include "helper_p.h"
 #include "feed.h"
 #include "fetchqueue.h"
 #include "treenodevisitor.h"
@@ -140,7 +141,7 @@ QList<const TreeNode *> Folder::children() const
 {
     QList<const TreeNode *> children;
     children.reserve(d->children.size());
-    Q_FOREACH (const TreeNode *i, d->children) {
+    for (const TreeNode *i : qAsConst(d->children)) {
         children.append(i);
     }
     return children;
@@ -154,7 +155,7 @@ QList<TreeNode *> Folder::children()
 QVector<const Akregator::Feed *> Folder::feeds() const
 {
     QHash<int, const Akregator::Feed *> feedsById;
-    Q_FOREACH (const TreeNode *i, d->children)
+    for (const TreeNode *i : qAsConst(d->children))
         Q_FOREACH (const Akregator::Feed *j, i->feeds()) {
             feedsById.insert(j->id(), j);
         }
@@ -165,7 +166,7 @@ QVector<const Akregator::Feed *> Folder::feeds() const
 QVector<Akregator::Feed *> Folder::feeds()
 {
     QHash<int, Akregator::Feed *> feedsById;
-    Q_FOREACH (TreeNode *i, d->children)
+    for (TreeNode *i : qAsConst(d->children))
         Q_FOREACH (Akregator::Feed *j, i->feeds()) {
             feedsById.insert(j->id(), j);
         }
@@ -177,7 +178,7 @@ QVector<const Folder *> Folder::folders() const
 {
     QHash<int, const Folder *> foldersById;
     foldersById.insert(id(), this);
-    Q_FOREACH (const TreeNode *i, d->children)
+    for (const TreeNode *i : qAsConst(d->children))
         Q_FOREACH (const Folder *j, i->folders()) {
             foldersById.insert(j->id(), j);
         }
@@ -189,7 +190,7 @@ QVector<Folder *> Folder::folders()
 {
     QHash<int, Folder *> foldersById;
     foldersById.insert(id(), this);
-    Q_FOREACH (TreeNode *i, d->children)
+    for (TreeNode *i : qAsConst(d->children))
         Q_FOREACH (Folder *j, i->folders()) {
             foldersById.insert(j->id(), j);
         }
@@ -366,7 +367,7 @@ bool Folder::subtreeContains(const TreeNode *node) const
     if (node == this) {
         return false;
     }
-    const Folder *parent = node ? node->parent() : Q_NULLPTR;
+    const Folder *parent = node ? node->parent() : nullptr;
     while (parent) {
         if (parent == this) {
             return true;
@@ -414,7 +415,7 @@ void Folder::disconnectFromNode(TreeNode *child)
 TreeNode *Folder::childAt(int pos)
 {
     if (pos < 0 || pos >= d->children.count()) {
-        return 0;
+        return nullptr;
     }
     return d->children.at(pos);
 }
@@ -422,7 +423,7 @@ TreeNode *Folder::childAt(int pos)
 const TreeNode *Folder::childAt(int pos) const
 {
     if (pos < 0 || pos >= d->children.count()) {
-        return 0;
+        return nullptr;
     }
     return d->children.at(pos);
 }
@@ -445,7 +446,7 @@ TreeNode *Folder::next()
             p = p->parent();
         }
     }
-    return 0;
+    return nullptr;
 }
 
 const TreeNode *Folder::next() const
@@ -466,7 +467,7 @@ const TreeNode *Folder::next() const
             p = p->parent();
         }
     }
-    return 0;
+    return nullptr;
 }
 
 QList<const TreeNode *> Folder::namedChildren(const QString &title) const
