@@ -43,6 +43,7 @@
 #include "expireitemscommand.h"
 #include "importfeedlistcommand.h"
 #include "feed.h"
+#include "helper_p.h"
 #include "feedlist.h"
 #include "feedpropertiesdialog.h"
 #include "fetchqueue.h"
@@ -64,6 +65,7 @@
 #include "mainframe.h"
 #include <WebEngineViewer/ZoomActionMenu>
 #include "job/downloadarticlejob.h"
+#include <WebEngineViewer/LocalDataBaseManager>
 
 #include <QAction>
 #include <kfileitem.h>
@@ -113,6 +115,8 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
 {
     setObjectName(name);
 
+    WebEngineViewer::LocalDataBaseManager::self()->initialize();
+
     FeedListManagementInterface::setInstance(m_feedListManagementInterface);
 
     m_actionManager->initMainWidget(this);
@@ -415,7 +419,7 @@ void MainWidget::sendArticle(bool attach)
 
 void MainWidget::cleanUpDownloadFile()
 {
-    Q_FOREACH (QPointer<Akregator::DownloadArticleJob> job, mListDownloadArticleJobs) {
+    for (QPointer<Akregator::DownloadArticleJob> job : qAsConst(mListDownloadArticleJobs)) {
         if (job) {
             job->forceCleanupTemporaryFile();
         }
@@ -507,9 +511,9 @@ QDomDocument MainWidget::feedListToOPML()
 void MainWidget::addFeedToGroup(const QString &url, const QString &groupName)
 {
     // Locate the group.
-    QList<TreeNode *> namedGroups = m_feedList->findByTitle(groupName);
-    Folder *group = 0;
-    foreach (TreeNode *const candidate, namedGroups) {
+    const QList<TreeNode *> namedGroups = m_feedList->findByTitle(groupName);
+    Folder *group = nullptr;
+    for (TreeNode *const candidate : namedGroups) {
         if (candidate->isGroup()) {
             group =  static_cast<Folder *>(candidate);
             break;
@@ -699,7 +703,7 @@ void MainWidget::slotNodeSelected(TreeNode *node)
 
 void MainWidget::slotFeedAdd()
 {
-    Folder *group = 0;
+    Folder *group = nullptr;
     if (!m_selectionController->selectedSubscription()) {
         group = m_feedList->allFeedsFolder();
     } else {
@@ -711,7 +715,7 @@ void MainWidget::slotFeedAdd()
 
     }
 
-    TreeNode *const lastChild = !group->children().isEmpty() ? group->children().last() : Q_NULLPTR;
+    TreeNode *const lastChild = !group->children().isEmpty() ? group->children().last() : nullptr;
 
     addFeed(QString(), lastChild, group, false);
 }
@@ -887,7 +891,7 @@ void MainWidget::slotArticleSelected(const Akregator::Article &article)
     maai->setChecked(article.keep());
 
     m_articleViewer->showArticle(article);
-    if (m_selectionController->selectedArticles().count() == 0) {
+    if (m_selectionController->selectedArticles().isEmpty()) {
         m_articleListView->setCurrentIndex(m_selectionController->currentArticleIndex());
     }
 
@@ -960,7 +964,7 @@ void MainWidget::slotOpenSelectedArticlesInBrowser()
 {
     const QVector<Article> articles = m_selectionController->selectedArticles();
 
-    Q_FOREACH (const Akregator::Article &article, articles) {
+    for (const Akregator::Article &article : articles) {
         slotOpenArticleInBrowser(article);
     }
 }
@@ -978,7 +982,7 @@ void MainWidget::openSelectedArticles(bool openInBackground)
 {
     const QVector<Article> articles = m_selectionController->selectedArticles();
 
-    Q_FOREACH (const Akregator::Article &article, articles) {
+    for (const Akregator::Article &article : articles) {
         const QUrl url = article.link();
         if (!url.isValid()) {
             continue;
@@ -1082,7 +1086,7 @@ void MainWidget::slotArticleDelete()
     }
 
     Akregator::ArticleDeleteJob *job = new Akregator::ArticleDeleteJob;
-    Q_FOREACH (const Akregator::Article &i, articles) {
+    for (const Akregator::Article &i : articles) {
         Feed *const feed = i.feed();
         if (!feed) {
             continue;
@@ -1113,7 +1117,7 @@ void MainWidget::slotArticleToggleKeepFlag(bool)
     }
 
     bool allFlagsSet = true;
-    Q_FOREACH (const Akregator::Article &i, articles) {
+    for (const Akregator::Article &i : articles) {
         allFlagsSet = allFlagsSet && i.keep();
         if (!allFlagsSet) {
             break;
@@ -1121,7 +1125,7 @@ void MainWidget::slotArticleToggleKeepFlag(bool)
     }
 
     Akregator::ArticleModifyJob *job = new Akregator::ArticleModifyJob;
-    Q_FOREACH (const Akregator::Article &i, articles) {
+    for (const Akregator::Article &i : articles) {
         const Akregator::ArticleId aid = { i.feed()->xmlUrl(), i.guid() };
         job->setKeep(aid, !allFlagsSet);
     }
@@ -1150,7 +1154,7 @@ void setSelectedArticleStatus(const Akregator::AbstractSelectionController *cont
     }
 
     Akregator::ArticleModifyJob *job = new Akregator::ArticleModifyJob;
-    Q_FOREACH (const Akregator::Article &i, articles) {
+    for (const Akregator::Article &i : articles) {
         const Akregator::ArticleId aid = { i.feed()->xmlUrl(), i.guid() };
         job->setStatus(aid, status);
     }
@@ -1204,7 +1208,7 @@ void MainWidget::readProperties(const KConfigGroup &config)
     // Reopen tabs
     const QStringList childList = config.readEntry(QStringLiteral("Children"), QStringList());
     int currentFrameId = -1;
-    Q_FOREACH (const QString &framePrefix, childList) {
+    for (const QString &framePrefix : childList) {
         WebEngineFrame *const frame = new WebEngineFrame(m_actionManager->actionCollection(), m_tabWidget);
         frame->loadConfig(config, framePrefix + QLatin1Char('_'));
 
